import aiohttp
from maubot import Plugin, MessageEvent
from maubot.handlers import command
from mautrix.types import MessageType, MediaMessageEventContent


class CatBot(Plugin):
    async def start(self) -> None:
        self.http = aiohttp.ClientSession()

    async def stop(self) -> None:
        await self.http.close()

    @command.new("cat")
    async def cat_command(self, evt: MessageEvent) -> None:
        async with self.http.get("https://cataas.com/cat") as response:
            if response.status == 200:
                image_data = await response.read()
                mxc_uri = await self.client.upload_media(image_data, mime_type="image/jpeg")
                await evt.respond(
                    content=MediaMessageEventContent(
                        url=mxc_uri,
                        body="cat",
                        msgtype=MessageType.IMAGE,
                    )
                )
            else:
                await evt.reply("couldn't fetch a cat image :(")

    @command.new("dog")
    async def dog_command(self, evt: MessageEvent) -> None:
        async with self.http.get("https://random.dog/woof.json") as response:
            if response.status == 200:
                image_link = await response.json()
            else:
                await evt.reply("couldn't fetch a dog image :(")
                return

        async with self.http.get(image_link['url']) as response:
            if response.status == 200:
                image_data = await response.read()
                mxc_uri = await self.client.upload_media(image_data, mime_type="image/jpeg")
                await evt.respond(
                    content=MediaMessageEventContent(
                        url=mxc_uri,
                        body="dog",
                        msgtype=MessageType.IMAGE,
                    )
                )
            else:
                await evt.reply("couldn't fetch a dog image :(")
